# Damnson

This gem provides your rails app a floating control panel for your non-production environments.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'damnson'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install damnson

## Usage

Create a controller for your actions

```ruby
# panel_controller.rb

class PanelController < ApplicationController
  unless Rails.env.production?
    def do_some_stuff
      # Code here
      redirect_to :back
    end
  end
end

```

Create the associated routes wrapped in non-production condition

```ruby
# routes.rb

unless Rails.env.production?
  get 'panel/awesome', to: 'panel#do_some_stuff', as: :damnson
end

```

Call damnson with the actions required

```ruby
# _javascript.html.erb

<% unless Rails.env.production? %>
  <%
    ds_opts = {}
    ds_opts[:items] = [
        { label: 'Create some projects', path: damnson_path },
        { label: 'Add random contributions', path: damnson_path },
        { label: 'Delete everything', path: damnson_path },
        { label: 'Add random data', path: damnson_path }
    ]
  %>
  <%= javascript_tag do %>
    damnson(<%= raw ds_opts.to_json %>)
  <% end %>
<% end %>
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/terry90/damnson. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.


## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

